# sdss_brain

![Versions](https://img.shields.io/badge/python->3.7-blue)
[![Documentation Status](https://readthedocs.org/projects/sdss-brain/badge/?version=latest)](https://sdss-brain.readthedocs.io/en/latest/?badge=latest)
[![Travis (.org)](https://img.shields.io/travis/sdss/sdss_brain)](https://travis-ci.org/sdss/sdss_brain)
[![codecov](https://codecov.io/gh/sdss/sdss_brain/branch/master/graph/badge.svg)](https://codecov.io/gh/sdss/sdss_brain)
[![Coveralls](https://coveralls.io/repos/github/sdss/sdss_brain/badge.svg)](https://coveralls.io/github/sdss/sdss_brain)

SDSS product for streamlining and simplifying user experiences around SDSS data products.  
It combines the utility of other core SDSS packages, e.g. 
[sdss-access](https://github.com/sdss/sdss_access), [sdss-tree](https://github.com/sdss/tree), [sdssdb](https://github.com/sdss/sdssdb), [sdsstools](https://github.com/sdss/sdsstools) to enable more high level interaction between the SDSS data products.

**sdss_brain is in active development. Although the code is stable and can be used for production, the implementation of existing features may be changed without previous notice. This will change when we reach version 1.0.0.**

Useful links
------------

- GitHub: https://github.com/sdss/sdss_brain
- Documentation: https://sdss-brain.readthedocs.org
- Issues: https://github.com/sdss/sdss_brain/issues

